<template>
    <el-dialog
        :visible.sync="detailVisible"
        :close-on-click-modal="false"
        width="60%"
    >
        <div class="table_content">
            <el-table
                v-loading="listLoading"
                :key="tableKey"
                :data="detailData"
                border
                fit
                highlight-current-row
                style="width: 100%;"
            >
                <el-table-column label="序号" type="index" align="center" width="60"/>
                <el-table-column label="企业名称" prop="enterprisename" align="center">
                </el-table-column>
                <el-table-column label="进货数量(箱)" prop="innum" align="center">
                </el-table-column>
                <el-table-column label="出货数量(箱)" prop="outnum" align="center">
                </el-table-column>
                <el-table-column label="销售数量(箱)" prop="salenum" align="center">
                </el-table-column>
                <el-table-column label="销售额(万元)" prop="sales" align="center">
                </el-table-column>
            </el-table>
            <br>
            <el-pagination
                v-show="recordTotal>0"
                :current-page="currentPage"
                :page-sizes="[10, 20, 30, 50]"
                :page-size="pageSize"
                :total="recordTotal"
                layout="total, sizes, prev, pager, next, jumper"
                background
                style="float:right;"
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"
            />
            <br>
        </div>
    </el-dialog>
</template>

<script>
import {getCityInAndOutDetail} from "@/api/productPurchaseSearch";
import {computePageCount} from "../../../utils";

export default {
    name: "index",
    data(){
        return{
            tableKey:'',
            listLoading:false,
            pageSize: 10,
            recordTotal: 0,
            currentPage: 1,
            pageTotal: 0,
            detailData:[],
            detailVisible:false,
            listQuery: {
                pageSize:10,
                pageIndex:1,
                filter: {
                    starttime: '',
                    endtime: '',
                    safetysupervision:''
                },
            },
        }
    },
    created() {

    },
    methods:{
      openDialog(params){
            this.listQuery.filter.city = params.city
            this.listQuery.filter.starttime = params.starttime
            this.listQuery.filter.endtime = params.endtime
            this.listQuery.filter.safetysupervision = params.safetysupervision
            this.detailVisible = true
            this.getCityInAndOutDetail()
        },
         async getCityInAndOutDetail(){
            this.listLoading = true
            let res = await getCityInAndOutDetail(this.listQuery)
            if(res.data.code === "200"){
                this.recordTotal = res.data.result.total
                this.pageSize = res.data.result.size
                this.pageTotal = computePageCount(res.data.result.total, res.data.result.size)
                this.currentPage = res.data.result.current
                this.detailData = res.data.result.records
            }else{
                this.$message({
                    type:'warning',
                    message:res.data.message
                })
            }
            this.listLoading = false
        },
        handleSizeChange(val) {
            this.listQuery.pageSize = val
            this.getCityInAndOutDetail()
        },
        handleCurrentChange(val) {
            this.listQuery.pageIndex = val
            this.getCityInAndOutDetail()
        },
    }
}
</script>

<style scoped>

</style>
